@@ -33,7 +33,7 @@
 #include <tr1/memory>
 #include <stdlib.h>
 #include <sstream>
-#include "Cache.h"
+#include "CacheMemory.h"
 #include "ChannelLayouts.h"
 #include "Fraction.h"
 #include "Frame.h"
@@ -99,6 +99,9 @@ namespace openshot
 	    CriticalSection getFrameCriticalSection;
 	    CriticalSection processingCriticalSection;
 
+		int max_width; ///< The maximum image width needed by this clip (used for optimizations)
+		int max_height; ///< The maximium image height needed by this clip (used for optimizations)
+
 	public:
 
 		/// Constructor for the base reader, where many things are initialized.
@@ -113,11 +116,8 @@ namespace openshot
 		/// Display file information in the standard output stream (stdout)
 		void DisplayInfo();
 
-		/// Test method to draw a bitmap on a Qt QGraphicsScene
-		void DrawFrameOnScene(string path, long _graphics_scene_address);
-
 		/// Get the cache object used by this reader (note: not all readers use cache)
-		virtual Cache* GetCache() = 0;
+		virtual CacheBase* GetCache() = 0;
 
 		/// This method is required for all derived classes of ReaderBase, and returns the
 		/// openshot::Frame object, which contains the image and audio information for that
@@ -127,9 +127,6 @@ namespace openshot
 		/// @param[in] number The frame number that is requested.
 		virtual tr1::shared_ptr<Frame> GetFrame(long int number) = 0;
 
-	    /// A thread safe version of GetFrame.
-	    //tr1::shared_ptr<Frame> GetFrameSafe(int number);
-
 		/// Determine if reader is open or closed
 		virtual bool IsOpen() = 0;
 
@@ -142,6 +139,9 @@ namespace openshot
 		virtual Json::Value JsonValue() = 0; ///< Generate Json::JsonValue for this object
 		virtual void SetJsonValue(Json::Value root) = 0; ///< Load Json::JsonValue into this object
 
+		/// Set Max Image Size (used for performance optimization)
+		void SetMaxSize(int width, int height) { max_width = width; max_height = height; };
+
 		/// Open the reader (and start consuming resources, such as images or video files)
 		virtual void Open() = 0;
 	};
